==> viha-5.15.tar.gz: viha-5.15/hlo0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = "hlo0.php";

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Henkiltiedot</title>
</head>
" . body_bgcolor() . "
<h1>Henkilkohtaisten tietojen ksittely ja henkiliden siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$nimi = get_txt('nimi');
$puhelin = get_txt('puhelin');
$ryhma_id = get_nro_1('ryhma_id');
$hlo_tila_id = get_nro_1('hlo_tila_id');
$hlo_asema_id = get_nro('hlo_asema_id');
if ($hlo_asema_id == "") { $hlo_asema_id = "5"; }
$jarjesto_id = get_nro_1('jarjesto_id');
$halyssa = get_nro_1('halyssa');
$ra = get_txt('ra');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = hlo_add_ok($herja,$alue_id,$paivystys_id,$nimi,$ryhma_id,$hlo_tila_id,
		    $hlo_asema_id,$jarjesto_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO hlo
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           nimi = '$nimi',
           puhelin = '$puhelin',
           ryhma_id = $ryhma_id,
           hlo_tila_id = $hlo_tila_id,
           hlo_asema_id = $hlo_asema_id,
           jarjesto_id = $jarjesto_id,
           halyssa = 1,
           ra = '$ra',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    taktinen_loki("Listty henkil $nimi, ryhm " . ota_kutsu($ryhma_id)
		  . ", tila " . ota_hlo_tila($hlo_tila_id)
		  . ", asema " . ota_hlo_asema($hlo_asema_id));
    add_hlo_ajat($new_id);
    echo "<p>Tiedot listty.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = hlo_save_ok($herja,$id,$alue_id,$paivystys_id,$nimi,$ryhma_id,
		     $hlo_tila_id,$hlo_asema_id,$jarjesto_id);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           nimi = '$nimi',
           puhelin = '$puhelin',
           ryhma_id = $ryhma_id,
           hlo_tila_id = $hlo_tila_id,
           hlo_asema_id = $hlo_asema_id,
           jarjesto_id = $jarjesto_id,
           ra = '$ra',
           ts = '$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    taktinen_loki("Muutettu henkil " . ota_nimi($id)
		  . ", ryhm " . ota_kutsu($ryhma_id)
		  . ", tila " . ota_hlo_tila($hlo_tila_id)
		  . ", asema " . ota_hlo_asema($hlo_asema_id));
    add_hlo_ajat($id);
    echo "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = hlo_remove_ok($herja,$id);
  if ($ret != 2) {
    taktinen_loki("Poistetaan henkil "
		  . ota_nimi($id));
    $sql = "DELETE FROM hlo WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    # poistetaan samalla tyaikaleimaukset
    $sql = "DELETE FROM hlo_ajat WHERE hlo_id = $id";
    $result = my_mysql_query ($sql,true,true);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $paivystys_id = "1";
    $nimi = '';
    $puhelin = '';
    $ryhma_id = "1";
    $hlo_tila_id = "1";
    $hlo_asema_id = "5";
    $jarjesto_id = "1";
    $halyssa = "1";
    $ra = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = hlo_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM hlo WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $nimi = $a['nimi'];
  $puhelin = $a['puhelin'];
  $ryhma_id = $a['ryhma_id'];
  $hlo_tila_id = $a['hlo_tila_id'];
  $hlo_asema_id = $a['hlo_asema_id'];
  $jarjesto_id = $a['jarjesto_id'];
  $halyssa = $a['halyssa'];
  $ra = $a['ra']; 
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Nimi:";
if ($readonly) {
  echo "<td>$nimi\n";
} else {
  echo "<td><input type=\"text\" name=\"nimi\" size=64 maxlength=64";
  echo " value=\"$nimi\"> Sukunimi Etunimi\n";
}

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Puhelin:";
if ($readonly) {
  echo "<td>$puhelin\n";
} else {
  echo "<td><input type=\"text\" name=\"puhelin\" size=32 maxlength=32";
  echo " value=\"$puhelin\">\n";
}

echo "<tr><td>Ryhm:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT kutsu FROM ryhma WHERE id = $ryhma_id") . "\n";
 } else {
  echo "<td>\n";
  select_ryhma_full($ryhma_id);
 }

echo "<tr><td>Tila:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT hlo_tila FROM hlo_tila WHERE id = $hlo_tila_id") . "\n";
} else {
  echo "<td>\n";
  select_hlo_tila_full($hlo_tila_id);
}

echo "<tr><td>Asema:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT hlo_asema FROM hlo_asema WHERE id = $hlo_asema_id")
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("hlo_asema_id", $hlo_asema_id, "hlo_asema", "id", "hlo_asema",
	      "ORDER BY pri");
}

echo "<tr><td>Jrjest:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT jarjesto FROM jarjesto WHERE id = $jarjesto_id")
    . "\n";
 } else {
  echo "<td>\n";
  select_jarjesto_full($jarjesto_id);
 }

echo "<tr><td>Listieto:";
if ($readonly) {
  echo "<td>$ra\n";
} else {
  echo "<td><input type=\"text\" name=\"ra\" size=16 maxlength=16";
  echo " value=\"$ra\"> (koulutus, radioamatrikutsu, tms)\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT hlo.id, hlo.alue_id, hlo.paivystys_id, hlo.nimi, hlo.puhelin,
       ryhma.kutsu,
       hlo_tila.hlo_tila, hlo.ra, hlo.ts, hlo_asema, jarjesto
FROM hlo, ryhma, hlo_tila, hlo_asema, jarjesto
WHERE ryhma.id = hlo.ryhma_id AND hlo_tila.id = hlo.hlo_tila_id
      AND hlo_asema.id = hlo_asema_id AND jarjesto.id = jarjesto_id
ORDER BY hlo.nimi
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Nimi<TH>Alue<TH>Operaatio<TH>Ryhm"
    . "<TH>Tila<TH>Asema<TH>Jrjest\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[nimi]",
      "<TD>". tab_col_id("alue","",$a['alue_id']),
      "<TD>". tab_col_id("paivystys","nimi",$a['paivystys_id']),
      "<td>$a[kutsu]",
      "<td>$a[hlo_tila]",
      "<td>$a[hlo_asema]",
      "<td>$a[jarjesto]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a> ";
      echo "<a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a> ";
      echo "<a href=\"hlo-historia.php?id=$a[id]\">HISTORIA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei henkiltietoja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo0.php,v 1.24 2009/05/10 08:44:28 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/hlo0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = "hlo0.php";

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Henkiltiedot</title>
</head>
" . body_bgcolor() . "
<h1>Henkilkohtaisten tietojen ksittely ja henkiliden siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$nimi = get_txt('nimi');
$puhelin = get_txt('puhelin');
$ryhma_id = get_nro_1('ryhma_id');
$hlo_tila_id = get_nro_1('hlo_tila_id');
$hlo_asema_id = get_nro('hlo_asema_id');
if ($hlo_asema_id == "") { $hlo_asema_id = "5"; }
$jarjesto_id = get_nro_1('jarjesto_id');
$halyssa = get_nro_1('halyssa');
$ra = get_txt('ra');
$osaaminen_ids = get_multi_nro('osaaminen_ids');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = hlo_add_ok($herja,$alue_id,$paivystys_id,$nimi,$ryhma_id,$hlo_tila_id,
		    $hlo_asema_id,$jarjesto_id,$osaaminen_ids);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO hlo
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           nimi = '$nimi',
           puhelin = '$puhelin',
           ryhma_id = $ryhma_id,
           hlo_tila_id = $hlo_tila_id,
           hlo_asema_id = $hlo_asema_id,
           jarjesto_id = $jarjesto_id,
           halyssa = 1,
           ra = '$ra',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    set_osaaminen_ids($now,$new_id,$osaaminen_ids);
    taktinen_loki("Listty henkil $nimi, ryhm " . ota_kutsu($ryhma_id)
		  . ", tila " . ota_hlo_tila($hlo_tila_id)
		  . ", asema " . ota_hlo_asema($hlo_asema_id));
    add_hlo_ajat($new_id);
    echo "<p>Tiedot listty.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = hlo_save_ok($herja,$id,$alue_id,$paivystys_id,$nimi,$ryhma_id,
		     $hlo_tila_id,$hlo_asema_id,$jarjesto_id,$osaaminen_ids);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           nimi = '$nimi',
           puhelin = '$puhelin',
           ryhma_id = $ryhma_id,
           hlo_tila_id = $hlo_tila_id,
           hlo_asema_id = $hlo_asema_id,
           jarjesto_id = $jarjesto_id,
           ra = '$ra',
           ts = '$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    set_osaaminen_ids($now,$id,$osaaminen_ids);
    taktinen_loki("Muutettu henkil " . ota_nimi($id)
		  . ", ryhm " . ota_kutsu($ryhma_id)
		  . ", tila " . ota_hlo_tila($hlo_tila_id)
		  . ", asema " . ota_hlo_asema($hlo_asema_id));
    add_hlo_ajat($id);
    echo "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = hlo_remove_ok($herja,$id);
  if ($ret != 2) {
    taktinen_loki("Poistetaan henkil "
		  . ota_nimi($id));
    $sql = "DELETE FROM hlo WHERE id = $id";
    my_mysql_query ($sql,true,true);
    # poistetaan samalla tyaikaleimaukset
    $sql = "DELETE FROM hlo_ajat WHERE hlo_id = $id";
    my_mysql_query ($sql,true,true);
    $sql = "DELETE FROM osaaminen_hlo WHERE hlo_id = $id";
    my_mysql_query ($sql,true,true);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
  $id = "0";
  $paivystys_id = "1";
  $nimi = '';
  $puhelin = '';
  $ryhma_id = "1";
  $hlo_tila_id = "1";
  $hlo_asema_id = "5";
  $jarjesto_id = "1";
  $halyssa = "1";
  $ra = '';
  $osaaminen_ids = array();
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = hlo_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM hlo WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $nimi = $a['nimi'];
  $puhelin = $a['puhelin'];
  $ryhma_id = $a['ryhma_id'];
  $hlo_tila_id = $a['hlo_tila_id'];
  $hlo_asema_id = $a['hlo_asema_id'];
  $jarjesto_id = $a['jarjesto_id'];
  $halyssa = $a['halyssa'];
  $ra = $a['ra']; 
  $osaaminen_ids = fetch_osaaminen_ids($id);
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Nimi:";
if ($readonly) {
  echo "<td>$nimi\n";
} else {
  echo "<td><input type=\"text\" name=\"nimi\" size=64 maxlength=64";
  echo " value=\"$nimi\"> Sukunimi Etunimi\n";
}

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Puhelin:";
if ($readonly) {
  echo "<td>$puhelin\n";
} else {
  echo "<td><input type=\"text\" name=\"puhelin\" size=32 maxlength=32";
  echo " value=\"$puhelin\">\n";
}

echo "<tr><td>Ryhm:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT kutsu FROM ryhma WHERE id = $ryhma_id") . "\n";
 } else {
  echo "<td>\n";
  select_ryhma_full($ryhma_id);
 }

echo "<tr><td>Tila:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT hlo_tila FROM hlo_tila WHERE id = $hlo_tila_id") . "\n";
} else {
  echo "<td>\n";
  select_hlo_tila_full($hlo_tila_id);
}

echo "<tr><td>Asema:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT hlo_asema FROM hlo_asema WHERE id = $hlo_asema_id")
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("hlo_asema_id", $hlo_asema_id, "hlo_asema", "id", "hlo_asema",
	      "ORDER BY pri");
}

echo "<tr><td>Jrjest:";
if ($readonly) {
  echo "<td>"
    . ota_yksi("SELECT jarjesto FROM jarjesto WHERE id = $jarjesto_id")
    . "\n";
 } else {
  echo "<td>\n";
  select_jarjesto_full($jarjesto_id);
 }

echo "<tr><td>Listieto:";
if ($readonly) {
  echo "<td>$ra\n";
} else {
  echo "<td><input type=\"text\" name=\"ra\" size=16 maxlength=16";
  echo " value=\"$ra\"> (koulutus, radioamatrikutsu, tms)\n";
}

echo "<tr><td>Osaamisprofiili:";
if ($readonly) {
  echo "<td>\n";
  list_osaaminen_ids($osaaminen_ids);
 }  else {
  echo "<td>\n";
  select_osaaminen_ids($id);
 }

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT hlo.id, hlo.alue_id, hlo.paivystys_id, hlo.nimi, hlo.puhelin,
       ryhma.kutsu,
       hlo_tila.hlo_tila, hlo.ra, hlo.ts, hlo_asema, jarjesto
FROM hlo, ryhma, hlo_tila, hlo_asema, jarjesto
WHERE ryhma.id = hlo.ryhma_id AND hlo_tila.id = hlo.hlo_tila_id
      AND hlo_asema.id = hlo_asema_id AND jarjesto.id = jarjesto_id
ORDER BY hlo.nimi
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Nimi<TH>Alue<TH>Operaatio<TH>Ryhm"
    . "<TH>Tila<TH>Asema<TH>Jrjest<TH>OP\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[nimi]",
      "<TD>". tab_col_id("alue","",$a['alue_id']),
      "<TD>". tab_col_id("paivystys","nimi",$a['paivystys_id']),
      "<td>$a[kutsu]",
      "<td>$a[hlo_tila]",
      "<td>$a[hlo_asema]",
      "<td>$a[jarjesto]",
      "<TD>" . ota_yksi("SELECT COUNT(*)
                         FROM osaaminen_hlo
                         WHERE hlo_id = $a[id]");
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a> ";
      echo "<a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a> ";
      echo "<a href=\"hlo-historia.php?id=$a[id]\">HISTORIA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei henkiltietoja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo0.php,v 1.30 2009/10/06 08:19:56 riku Exp $ -->
